/**
 * Gracefully adds a forward property to the global Partytown config. This
 * first ensures the `window.partytown.foward` exists, then adds the forward
 * property.
 *
 * @public
 */
export declare const appendForwardProperty: (propertyName: PartytownForwardPropertyName, propertyType?: PartytownForwardPropertyType) => string;

/**
 * @public
 */
export declare interface PartytownConfig {
    /**
     * When set to `true`, Partytown scripts are not inlined and not minified.
     */
    debug?: boolean;
    /**
     * Many third-party scripts provide a global variable which user code calls
     * in order to send data to the service. For example, Google Tag Manager uses
     * a [Data Layer](https://developers.google.com/tag-manager/devguide) array,
     * and by pushing data to the array, the data is then sent on to GTM. Because
     * we're moving third-party scripts to a web worker, the main thread needs to
     * know which variables to patch first, and when Partytown loads, it can then
     * forward the event data on to the service.
     *
     * Below is an example of Google Tag Manager, Hubspot and Intercom forward configs:
     *
     * ```js
     * [['dataLayer', 1], ['_hsq', 1], ['Intercom']]
     * ```
     */
    forward?: PartytownForwardProperty[];
    /**
     * Root directory the Partytown library files can be found.
     * The library path must end with a `/`.
     * By default the files will load from the server's `/~partytown/` directory.
     */
    lib?: string;
    /**
     * Log method calls (debug mode required)
     */
    logCalls?: boolean;
    /**
     * Log getter calls (debug mode required)
     */
    logGetters?: boolean;
    /**
     * Log setter calls (debug mode required)
     */
    logSetters?: boolean;
    /**
     * Log Image() src requests (debug mode required)
     */
    logImageRequests?: boolean;
    /**
     * Log script executions (debug mode required)
     */
    logScriptExecution?: boolean;
    /**
     * Log navigator.sendBeacon() requests (debug mode required)
     */
    logSendBeaconRequests?: boolean;
    /**
     * Log stack traces (debug mode required)
     */
    logStackTraces?: boolean;
}

/**
 * A foward property to patch on the global. The foward config property is an array,
 * with the value at index 0 being the property name to patch. Optionally, the value
 * at index 1 can set what type of property it is. By default it is patched as a
 * function, and when set to `1`, it is patched as an array.
 *
 * @public
 */
declare type PartytownForwardProperty = [
PartytownForwardPropertyName,
PartytownForwardPropertyFunctionType?
];

/**
 * Sets the forward property as an array.
 *
 * @public
 */
declare type PartytownForwardPropertyArrayType = 1;

/**
 * Default foward property type, which sets the property as a function.
 *
 * @public
 */
declare type PartytownForwardPropertyFunctionType = undefined;

/**
 * The property to patch on `window`, such as `dataLayer` for Google Tag Manager.
 *
 * @public
 */
export declare type PartytownForwardPropertyName = string;

/**
 * The type of property which is patched on `window`. For example, Google Tag Manager's
 * `dataLayer` is an array, so it's type should be `1`. The default, which is `undefined`,
 * treats the property as a function.
 *
 * @public
 */
export declare type PartytownForwardPropertyType = PartytownForwardPropertyArrayType | undefined;

/**
 * @public
 */
export declare const partytownSnippet: (config: PartytownConfig) => string;

/**
 * The `type` attribute for Partytown scripts, which does two things:
 *
 * 1. Prevents the `<script>` from executing on the main thread.
 * 2. Is used as a selector so the Partytown library can find all scripts to execute in a web worker.
 *
 * @public
 */
export declare const SCRIPT_TYPE = "text/partytown";

export { }
