/**
 * The Google Tag Manager Partytown component should be added after the opening `<head>`
 * tag, but before the `<Partytown/>` component. This component will add the
 * [Data Layer](https://developers.google.com/tag-manager/devguide) to the main thread
 * window, and will load GTM within the web worker. Any updates to `dataLayer.push(...)`
 * will be forwarded to the Partytown web worker.
 *
 * https://developers.google.com/tag-manager/quickstart
 *
 * @public
 */
export declare const GoogleTagManager: ({ containerId }: GoogleTagManagerProps) => any;

/**
 * The GTM No Script component should be added immediately after the opening `<body>` tag.
 *
 * https://developers.google.com/tag-manager/quickstart
 *
 * @public
 */
export declare const GoogleTagManagerNoScript: ({ containerId }: GoogleTagManagerProps) => any;

/**
 * https://developers.google.com/tag-manager/quickstart
 *
 * @public
 */
export declare type GoogleTagManagerProps = {
    /**
     * Google Tag Manager Container ID, formatted as GTM-XXXXXX
     */
    containerId: string;
};

/**
 * The React `<Partytown/>` component should be placed within the `<head>`
 * of the document, and after any integrations such as `<GoogleTagManager/>`.
 *
 * @public
 */
export declare const Partytown: (props?: PartytownProps | undefined) => any;

/**
 * @public
 */
declare interface PartytownConfig {
    /**
     * When set to `true`, Partytown scripts are not inlined and not minified.
     */
    debug?: boolean;
    /**
     * Many third-party scripts provide a global variable which user code calls
     * in order to send data to the service. For example, Google Tag Manager uses
     * a [Data Layer](https://developers.google.com/tag-manager/devguide) array,
     * and by pushing data to the array, the data is then sent on to GTM. Because
     * we're moving third-party scripts to a web worker, the main thread needs to
     * know which variables to patch first, and when Partytown loads, it can then
     * forward the event data on to the service.
     *
     * Below is an example of Google Tag Manager, Hubspot and Intercom forward configs:
     *
     * ```js
     * [['dataLayer', 1], ['_hsq', 1], ['Intercom']]
     * ```
     */
    forward?: PartytownForwardProperty[];
    /**
     * Root directory the Partytown library files can be found.
     * The library path must end with a `/`.
     * By default the files will load from the server's `/~partytown/` directory.
     */
    lib?: string;
    /**
     * Log method calls (debug mode required)
     */
    logCalls?: boolean;
    /**
     * Log getter calls (debug mode required)
     */
    logGetters?: boolean;
    /**
     * Log setter calls (debug mode required)
     */
    logSetters?: boolean;
    /**
     * Log Image() src requests (debug mode required)
     */
    logImageRequests?: boolean;
    /**
     * Log script executions (debug mode required)
     */
    logScriptExecution?: boolean;
    /**
     * Log navigator.sendBeacon() requests (debug mode required)
     */
    logSendBeaconRequests?: boolean;
    /**
     * Log stack traces (debug mode required)
     */
    logStackTraces?: boolean;
}

/**
 * A foward property to patch on the global. The foward config property is an array,
 * with the value at index 0 being the property name to patch. Optionally, the value
 * at index 1 can set what type of property it is. By default it is patched as a
 * function, and when set to `1`, it is patched as an array.
 *
 * @public
 */
declare type PartytownForwardProperty = [
PartytownForwardPropertyName,
PartytownForwardPropertyFunctionType?
];

/**
 * Default foward property type, which sets the property as a function.
 *
 * @public
 */
declare type PartytownForwardPropertyFunctionType = undefined;

/**
 * The property to patch on `window`, such as `dataLayer` for Google Tag Manager.
 *
 * @public
 */
declare type PartytownForwardPropertyName = string;

/**
 * Props for `<Partytown/>`, which extends the Partytown Config.
 *
 * https://github.com/BuilderIO/partytown#config
 *
 * @public
 */
export declare interface PartytownProps extends PartytownConfig {
}

export { }
